statsapiclient: A client for the NHL stats API
==============================================

Purpose
-------

To provide a Python client to access the NHL's JSON API including game, play, and player data.

Installation
------------

TBD

Module Specs
------------

Schedule
^^^^^^^^

games_from_date

games_from_date_range


Games
^^^^^

game_line_score

game_play_by_play (TBD)

game_box_score (TBD)


Teams
^^^^^

teams_all

teams_by_conference

teams_by_division


Players
^^^^^^^

TBD


Examples
^^^^^^^^

TBD
